@@ -7,15 +7,15 @@
  */
 
 /**
- * Base WordPress Filesystem class for which Filesystem implementations extend
+ * Base WordPress Filesystem class which Filesystem implementations extend.
  *
  * @since 2.5.0
  */
 class WP_Filesystem_Base {
+
 	/**
 	 * Whether to display debug data for the connection.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @var bool
 	 */
@@ -24,7 +24,6 @@ class WP_Filesystem_Base {
 	/**
 	 * Cached list of local filepaths to mapped remote filepaths.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 * @var array
 	 */
@@ -33,98 +32,95 @@ class WP_Filesystem_Base {
 	/**
 	 * The Access method of the current connection, Set automatically.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @var string
 	 */
 	public $method = '';
 
 	/**
-	 * @access public
 	 * @var WP_Error
 	 */
 	public $errors = null;
 
 	/**
-	 * @access public
 	 */
 	public $options = array();
 
 	/**
-	 * Return the path on the remote filesystem of ABSPATH.
+	 * Returns the path on the remote filesystem of ABSPATH.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @return string The location of the remote path.
 	 */
 	public function abspath() {
-		$folder = $this->find_folder(ABSPATH);
-		// Perhaps the FTP folder is rooted at the WordPress install, Check for wp-includes folder in root, Could have some false positives, but rare.
-		if ( ! $folder && $this->is_dir( '/' . WPINC ) )
+		$folder = $this->find_folder( ABSPATH );
+
+		// Perhaps the FTP folder is rooted at the WordPress install.
+		// Check for wp-includes folder in root. Could have some false positives, but rare.
+		if ( ! $folder && $this->is_dir( '/' . WPINC ) ) {
 			$folder = '/';
+		}
+
 		return $folder;
 	}
 
 	/**
-	 * Return the path on the remote filesystem of WP_CONTENT_DIR.
+	 * Returns the path on the remote filesystem of WP_CONTENT_DIR.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @return string The location of the remote path.
 	 */
 	public function wp_content_dir() {
-		return $this->find_folder(WP_CONTENT_DIR);
+		return $this->find_folder( WP_CONTENT_DIR );
 	}
 
 	/**
-	 * Return the path on the remote filesystem of WP_PLUGIN_DIR.
+	 * Returns the path on the remote filesystem of WP_PLUGIN_DIR.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @return string The location of the remote path.
 	 */
 	public function wp_plugins_dir() {
-		return $this->find_folder(WP_PLUGIN_DIR);
+		return $this->find_folder( WP_PLUGIN_DIR );
 	}
 
 	/**
-	 * Return the path on the remote filesystem of the Themes Directory.
+	 * Returns the path on the remote filesystem of the Themes Directory.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
-	 * @param string $theme The Theme stylesheet or template for the directory.
+	 * @param string|false $theme Optional. The theme stylesheet or template for the directory.
+	 *                            Default false.
 	 * @return string The location of the remote path.
 	 */
 	public function wp_themes_dir( $theme = false ) {
 		$theme_root = get_theme_root( $theme );
 
-		// Account for relative theme roots
-		if ( '/themes' == $theme_root || ! is_dir( $theme_root ) )
+		// Account for relative theme roots.
+		if ( '/themes' === $theme_root || ! is_dir( $theme_root ) ) {
 			$theme_root = WP_CONTENT_DIR . $theme_root;
+		}
 
 		return $this->find_folder( $theme_root );
 	}
 
 	/**
-	 * Return the path on the remote filesystem of WP_LANG_DIR.
+	 * Returns the path on the remote filesystem of WP_LANG_DIR.
 	 *
-	 * @access public
 	 * @since 3.2.0
 	 *
 	 * @return string The location of the remote path.
 	 */
 	public function wp_lang_dir() {
-		return $this->find_folder(WP_LANG_DIR);
+		return $this->find_folder( WP_LANG_DIR );
 	}
 
 	/**
-	 * Locate a folder on the remote filesystem.
+	 * Locates a folder on the remote filesystem.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @deprecated 2.7.0 use WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir() instead.
 	 * @see WP_Filesystem::abspath()
@@ -139,15 +135,14 @@ class WP_Filesystem_Base {
 	 * @return string The location of the remote path.
 	 */
 	public function find_base_dir( $base = '.', $echo = false ) {
-		_deprecated_function(__FUNCTION__, '2.7.0', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
+		_deprecated_function( __FUNCTION__, '2.7.0', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
 		$this->verbose = $echo;
 		return $this->abspath();
 	}
 
 	/**
-	 * Locate a folder on the remote filesystem.
+	 * Locates a folder on the remote filesystem.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @deprecated 2.7.0 use WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir() methods instead.
 	 * @see WP_Filesystem::abspath()
@@ -161,150 +156,171 @@ class WP_Filesystem_Base {
 	 * @return string The location of the remote path.
 	 */
 	public function get_base_dir( $base = '.', $echo = false ) {
-		_deprecated_function(__FUNCTION__, '2.7.0', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
+		_deprecated_function( __FUNCTION__, '2.7.0', 'WP_Filesystem::abspath() or WP_Filesystem::wp_*_dir()' );
 		$this->verbose = $echo;
 		return $this->abspath();
 	}
 
 	/**
-	 * Locate a folder on the remote filesystem.
+	 * Locates a folder on the remote filesystem.
 	 *
 	 * Assumes that on Windows systems, Stripping off the Drive
-	 * letter is OK Sanitizes \\ to / in windows filepaths.
+	 * letter is OK Sanitizes \\ to / in Windows filepaths.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @param string $folder the folder to locate.
 	 * @return string|false The location of the remote path, false on failure.
 	 */
 	public function find_folder( $folder ) {
-		if ( isset( $this->cache[ $folder ] ) )
+		if ( isset( $this->cache[ $folder ] ) ) {
 			return $this->cache[ $folder ];
+		}
 
-		if ( stripos($this->method, 'ftp') !== false ) {
+		if ( stripos( $this->method, 'ftp' ) !== false ) {
 			$constant_overrides = array(
-				'FTP_BASE' => ABSPATH,
+				'FTP_BASE'        => ABSPATH,
 				'FTP_CONTENT_DIR' => WP_CONTENT_DIR,
-				'FTP_PLUGIN_DIR' => WP_PLUGIN_DIR,
-				'FTP_LANG_DIR' => WP_LANG_DIR
+				'FTP_PLUGIN_DIR'  => WP_PLUGIN_DIR,
+				'FTP_LANG_DIR'    => WP_LANG_DIR,
 			);
 
-			// Direct matches ( folder = CONSTANT/ )
+			// Direct matches ( folder = CONSTANT/ ).
 			foreach ( $constant_overrides as $constant => $dir ) {
-				if ( ! defined( $constant ) )
+				if ( ! defined( $constant ) ) {
 					continue;
-				if ( $folder === $dir )
+				}
+
+				if ( $folder === $dir ) {
 					return trailingslashit( constant( $constant ) );
+				}
 			}
 
-			// Prefix Matches ( folder = CONSTANT/subdir )
+			// Prefix matches ( folder = CONSTANT/subdir ),
 			foreach ( $constant_overrides as $constant => $dir ) {
-				if ( ! defined( $constant ) )
+				if ( ! defined( $constant ) ) {
 					continue;
-				if ( 0 === stripos( $folder, $dir ) ) { // $folder starts with $dir
+				}
+
+				if ( 0 === stripos( $folder, $dir ) ) { // $folder starts with $dir.
 					$potential_folder = preg_replace( '#^' . preg_quote( $dir, '#' ) . '/#i', trailingslashit( constant( $constant ) ), $folder );
 					$potential_folder = trailingslashit( $potential_folder );
 
 					if ( $this->is_dir( $potential_folder ) ) {
 						$this->cache[ $folder ] = $potential_folder;
+
 						return $potential_folder;
 					}
 				}
 			}
-		} elseif ( 'direct' == $this->method ) {
-			$folder = str_replace('\\', '/', $folder); // Windows path sanitisation
-			return trailingslashit($folder);
+		} elseif ( 'direct' === $this->method ) {
+			$folder = str_replace( '\\', '/', $folder ); // Windows path sanitisation.
+
+			return trailingslashit( $folder );
 		}
 
-		$folder = preg_replace('|^([a-z]{1}):|i', '', $folder); // Strip out windows drive letter if it's there.
-		$folder = str_replace('\\', '/', $folder); // Windows path sanitisation
+		$folder = preg_replace( '|^([a-z]{1}):|i', '', $folder ); // Strip out Windows drive letter if it's there.
+		$folder = str_replace( '\\', '/', $folder ); // Windows path sanitisation.
 
-		if ( isset($this->cache[ $folder ] ) )
+		if ( isset( $this->cache[ $folder ] ) ) {
 			return $this->cache[ $folder ];
+		}
 
-		if ( $this->exists($folder) ) { // Folder exists at that absolute path.
-			$folder = trailingslashit($folder);
+		if ( $this->exists( $folder ) ) { // Folder exists at that absolute path.
+			$folder                 = trailingslashit( $folder );
 			$this->cache[ $folder ] = $folder;
+
 			return $folder;
 		}
-		if ( $return = $this->search_for_folder($folder) )
+
+		$return = $this->search_for_folder( $folder );
+
+		if ( $return ) {
 			$this->cache[ $folder ] = $return;
+		}
+
 		return $return;
 	}
 
 	/**
-	 * Locate a folder on the remote filesystem.
+	 * Locates a folder on the remote filesystem.
 	 *
 	 * Expects Windows sanitized path.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @param string $folder The folder to locate.
 	 * @param string $base   The folder to start searching from.
-	 * @param bool   $loop   If the function has recursed, Internal use only.
+	 * @param bool   $loop   If the function has recursed. Internal use only.
 	 * @return string|false The location of the remote path, false to cease looping.
 	 */
 	public function search_for_folder( $folder, $base = '.', $loop = false ) {
-		if ( empty( $base ) || '.' == $base )
-			$base = trailingslashit($this->cwd());
+		if ( empty( $base ) || '.' === $base ) {
+			$base = trailingslashit( $this->cwd() );
+		}
 
-		$folder = untrailingslashit($folder);
+		$folder = untrailingslashit( $folder );
 
 		if ( $this->verbose ) {
-			/* translators: 1: folder to locate, 2: folder to start searching from */
+			/* translators: 1: Folder to locate, 2: Folder to start searching from. */
 			printf( "\n" . __( 'Looking for %1$s in %2$s' ) . "<br/>\n", $folder, $base );
 		}
 
-		$folder_parts = explode('/', $folder);
+		$folder_parts     = explode( '/', $folder );
 		$folder_part_keys = array_keys( $folder_parts );
-		$last_index = array_pop( $folder_part_keys );
-		$last_path = $folder_parts[ $last_index ];
+		$last_index       = array_pop( $folder_part_keys );
+		$last_path        = $folder_parts[ $last_index ];
 
 		$files = $this->dirlist( $base );
 
 		foreach ( $folder_parts as $index => $key ) {
-			if ( $index == $last_index )
+			if ( $index == $last_index ) {
 				continue; // We want this to be caught by the next code block.
+			}
 
 			/*
 			 * Working from /home/ to /user/ to /wordpress/ see if that file exists within
 			 * the current folder, If it's found, change into it and follow through looking
-			 * for it. If it cant find WordPress down that route, it'll continue onto the next
+			 * for it. If it can't find WordPress down that route, it'll continue onto the next
 			 * folder level, and see if that matches, and so on. If it reaches the end, and still
-			 * cant find it, it'll return false for the entire function.
+			 * can't find it, it'll return false for the entire function.
 			 */
-			if ( isset($files[ $key ]) ){
+			if ( isset( $files[ $key ] ) ) {
 
 				// Let's try that folder:
-				$newdir = trailingslashit(path_join($base, $key));
+				$newdir = trailingslashit( path_join( $base, $key ) );
+
 				if ( $this->verbose ) {
-					/* translators: %s: directory name */
+					/* translators: %s: Directory name. */
 					printf( "\n" . __( 'Changing to %s' ) . "<br/>\n", $newdir );
 				}
 
 				// Only search for the remaining path tokens in the directory, not the full path again.
 				$newfolder = implode( '/', array_slice( $folder_parts, $index + 1 ) );
-				if ( $ret = $this->search_for_folder( $newfolder, $newdir, $loop) )
+				$ret       = $this->search_for_folder( $newfolder, $newdir, $loop );
+
+				if ( $ret ) {
 					return $ret;
+				}
 			}
 		}
 
 		// Only check this as a last resort, to prevent locating the incorrect install.
 		// All above procedures will fail quickly if this is the right branch to take.
-		if (isset( $files[ $last_path ] ) ) {
+		if ( isset( $files[ $last_path ] ) ) {
 			if ( $this->verbose ) {
-				/* translators: %s: directory name */
-				printf( "\n" . __( 'Found %s' ) . "<br/>\n",  $base . $last_path );
+				/* translators: %s: Directory name. */
+				printf( "\n" . __( 'Found %s' ) . "<br/>\n", $base . $last_path );
 			}
-			return trailingslashit($base . $last_path);
+
+			return trailingslashit( $base . $last_path );
 		}
 
 		// Prevent this function from looping again.
-		// No need to proceed if we've just searched in /
-		if ( $loop || '/' == $base )
+		// No need to proceed if we've just searched in `/`.
+		if ( $loop || '/' === $base ) {
 			return false;
+		}
 
 		// As an extra last resort, Change back to / if the folder wasn't found.
 		// This comes into effect when the CWD is /home/user/ but WP is at /var/www/....
@@ -313,81 +329,82 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Return the *nix-style file permissions for a file.
+	 * Returns the *nix-style file permissions for a file.
 	 *
 	 * From the PHP documentation page for fileperms().
 	 *
-	 * @link https://secure.php.net/manual/en/function.fileperms.php
+	 * @link https://www.php.net/manual/en/function.fileperms.php
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 *
 	 * @param string $file String filename.
 	 * @return string The *nix-style representation of permissions.
 	 */
-	public function gethchmod( $file ){
+	public function gethchmod( $file ) {
 		$perms = intval( $this->getchmod( $file ), 8 );
-		if (($perms & 0xC000) == 0xC000) // Socket
+
+		if ( ( $perms & 0xC000 ) == 0xC000 ) { // Socket.
 			$info = 's';
-		elseif (($perms & 0xA000) == 0xA000) // Symbolic Link
+		} elseif ( ( $perms & 0xA000 ) == 0xA000 ) { // Symbolic Link.
 			$info = 'l';
-		elseif (($perms & 0x8000) == 0x8000) // Regular
+		} elseif ( ( $perms & 0x8000 ) == 0x8000 ) { // Regular.
 			$info = '-';
-		elseif (($perms & 0x6000) == 0x6000) // Block special
+		} elseif ( ( $perms & 0x6000 ) == 0x6000 ) { // Block special.
 			$info = 'b';
-		elseif (($perms & 0x4000) == 0x4000) // Directory
+		} elseif ( ( $perms & 0x4000 ) == 0x4000 ) { // Directory.
 			$info = 'd';
-		elseif (($perms & 0x2000) == 0x2000) // Character special
+		} elseif ( ( $perms & 0x2000 ) == 0x2000 ) { // Character special.
 			$info = 'c';
-		elseif (($perms & 0x1000) == 0x1000) // FIFO pipe
+		} elseif ( ( $perms & 0x1000 ) == 0x1000 ) { // FIFO pipe.
 			$info = 'p';
-		else // Unknown
+		} else { // Unknown.
 			$info = 'u';
+		}
 
-		// Owner
-		$info .= (($perms & 0x0100) ? 'r' : '-');
-		$info .= (($perms & 0x0080) ? 'w' : '-');
-		$info .= (($perms & 0x0040) ?
-					(($perms & 0x0800) ? 's' : 'x' ) :
-					(($perms & 0x0800) ? 'S' : '-'));
+		// Owner.
+		$info .= ( ( $perms & 0x0100 ) ? 'r' : '-' );
+		$info .= ( ( $perms & 0x0080 ) ? 'w' : '-' );
+		$info .= ( ( $perms & 0x0040 ) ?
+					( ( $perms & 0x0800 ) ? 's' : 'x' ) :
+					( ( $perms & 0x0800 ) ? 'S' : '-' ) );
 
-		// Group
-		$info .= (($perms & 0x0020) ? 'r' : '-');
-		$info .= (($perms & 0x0010) ? 'w' : '-');
-		$info .= (($perms & 0x0008) ?
-					(($perms & 0x0400) ? 's' : 'x' ) :
-					(($perms & 0x0400) ? 'S' : '-'));
+		// Group.
+		$info .= ( ( $perms & 0x0020 ) ? 'r' : '-' );
+		$info .= ( ( $perms & 0x0010 ) ? 'w' : '-' );
+		$info .= ( ( $perms & 0x0008 ) ?
+					( ( $perms & 0x0400 ) ? 's' : 'x' ) :
+					( ( $perms & 0x0400 ) ? 'S' : '-' ) );
+
+		// World.
+		$info .= ( ( $perms & 0x0004 ) ? 'r' : '-' );
+		$info .= ( ( $perms & 0x0002 ) ? 'w' : '-' );
+		$info .= ( ( $perms & 0x0001 ) ?
+					( ( $perms & 0x0200 ) ? 't' : 'x' ) :
+					( ( $perms & 0x0200 ) ? 'T' : '-' ) );
 
-		// World
-		$info .= (($perms & 0x0004) ? 'r' : '-');
-		$info .= (($perms & 0x0002) ? 'w' : '-');
-		$info .= (($perms & 0x0001) ?
-					(($perms & 0x0200) ? 't' : 'x' ) :
-					(($perms & 0x0200) ? 'T' : '-'));
 		return $info;
 	}
 
 	/**
-	 * Gets the permissions of the specified file or filepath in their octal format
+	 * Gets the permissions of the specified file or filepath in their octal format.
 	 *
-	 * @access public
 	 * @since 2.5.0
-	 * @param string $file
-	 * @return string the last 3 characters of the octal number
+	 *
+	 * @param string $file Path to the file.
+	 * @return string Mode of the file (the last 3 digits).
 	 */
 	public function getchmod( $file ) {
 		return '777';
 	}
 
 	/**
-	 * Convert *nix-style file permissions to a octal number.
+	 * Converts *nix-style file permissions to a octal number.
 	 *
 	 * Converts '-rw-r--r--' to 0644
 	 * From "info at rvgate dot nl"'s comment on the PHP documentation for chmod()
- 	 *
-	 * @link https://secure.php.net/manual/en/function.chmod.php#49614
 	 *
-	 * @access public
+	 * @link https://www.php.net/manual/en/function.chmod.php#49614
+	 *
 	 * @since 2.5.0
 	 *
 	 * @param string $mode string The *nix-style file permission.
@@ -395,223 +412,222 @@ class WP_Filesystem_Base {
 	 */
 	public function getnumchmodfromh( $mode ) {
 		$realmode = '';
-		$legal =  array('', 'w', 'r', 'x', '-');
-		$attarray = preg_split('//', $mode);
+		$legal    = array( '', 'w', 'r', 'x', '-' );
+		$attarray = preg_split( '//', $mode );
 
 		for ( $i = 0, $c = count( $attarray ); $i < $c; $i++ ) {
-		   if ($key = array_search($attarray[$i], $legal)) {
-			   $realmode .= $legal[$key];
-		   }
+			$key = array_search( $attarray[ $i ], $legal, true );
+
+			if ( $key ) {
+				$realmode .= $legal[ $key ];
+			}
 		}
 
-		$mode = str_pad($realmode, 10, '-', STR_PAD_LEFT);
-		$trans = array('-'=>'0', 'r'=>'4', 'w'=>'2', 'x'=>'1');
-		$mode = strtr($mode,$trans);
+		$mode  = str_pad( $realmode, 10, '-', STR_PAD_LEFT );
+		$trans = array(
+			'-' => '0',
+			'r' => '4',
+			'w' => '2',
+			'x' => '1',
+		);
+		$mode  = strtr( $mode, $trans );
 
-		$newmode = $mode[0];
+		$newmode  = $mode[0];
 		$newmode .= $mode[1] + $mode[2] + $mode[3];
 		$newmode .= $mode[4] + $mode[5] + $mode[6];
 		$newmode .= $mode[7] + $mode[8] + $mode[9];
+
 		return $newmode;
 	}
 
 	/**
-	 * Determine if the string provided contains binary characters.
+	 * Determines if the string provided contains binary characters.
 	 *
-	 * @access public
 	 * @since 2.7.0
 	 *
 	 * @param string $text String to test against.
-	 * @return bool true if string is binary, false otherwise.
+	 * @return bool True if string is binary, false otherwise.
 	 */
 	public function is_binary( $text ) {
 		return (bool) preg_match( '|[^\x20-\x7E]|', $text ); // chr(32)..chr(127)
 	}
 
 	/**
-	 * Change the ownership of a file / folder.
+	 * Changes the owner of a file or directory.
 	 *
 	 * Default behavior is to do nothing, override this in your subclass, if desired.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 *
-	 * @param string $file      Path to the file.
-	 * @param mixed  $owner     A user name or number.
-	 * @param bool   $recursive Optional. If set True changes file owner recursivly. Defaults to False.
-	 * @return bool Returns true on success or false on failure.
+	 * @param string     $file      Path to the file or directory.
+	 * @param string|int $owner     A user name or number.
+	 * @param bool       $recursive Optional. If set to true, changes file owner recursively.
+	 *                              Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function chown( $file, $owner, $recursive = false ) {
 		return false;
 	}
 
 	/**
-	 * Connect filesystem.
+	 * Connects filesystem.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @return bool True on success or false on failure (always true for WP_Filesystem_Direct).
+	 * @return bool True on success, false on failure (always true for WP_Filesystem_Direct).
 	 */
 	public function connect() {
 		return true;
 	}
 
 	/**
-	 * Read entire file into a string.
+	 * Reads entire file into a string.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Name of the file to read.
-	 * @return mixed|bool Returns the read data or false on failure.
+	 * @return string|false Read data on success, false on failure.
 	 */
 	public function get_contents( $file ) {
 		return false;
 	}
 
 	/**
-	 * Read entire file into an array.
+	 * Reads entire file into an array.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Path to the file.
-	 * @return array|bool the file contents in an array or false on failure.
+	 * @return array|false File contents in an array on success, false on failure.
 	 */
 	public function get_contents_array( $file ) {
 		return false;
 	}
 
 	/**
-	 * Write a string to a file.
+	 * Writes a string to a file.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file     Remote path to the file where to write the data.
-	 * @param string $contents The data to write.
-	 * @param int    $mode     Optional. The file permissions as octal number, usually 0644.
-	 * @return bool False on failure.
+	 * @param string    $file     Remote path to the file where to write the data.
+	 * @param string    $contents The data to write.
+	 * @param int|false $mode     Optional. The file permissions as octal number, usually 0644.
+	 *                            Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function put_contents( $file, $contents, $mode = false ) {
 		return false;
 	}
 
 	/**
-	 * Get the current working directory.
+	 * Gets the current working directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @return string|bool The current working directory on success, or false on failure.
+	 * @return string|false The current working directory on success, false on failure.
 	 */
 	public function cwd() {
 		return false;
 	}
 
 	/**
-	 * Change current directory.
+	 * Changes current directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $dir The new current directory.
-	 * @return bool|string
+	 * @return bool True on success, false on failure.
 	 */
 	public function chdir( $dir ) {
 		return false;
 	}
 
 	/**
-	 * Change the file group.
+	 * Changes the file group.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file      Path to the file.
-	 * @param mixed  $group     A group name or number.
-	 * @param bool   $recursive Optional. If set True changes file group recursively. Defaults to False.
-	 * @return bool|string
+	 * @param string     $file      Path to the file.
+	 * @param string|int $group     A group name or number.
+	 * @param bool       $recursive Optional. If set to true, changes file group recursively.
+	 *                              Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function chgrp( $file, $group, $recursive = false ) {
 		return false;
 	}
 
 	/**
-	 * Change filesystem permissions.
+	 * Changes filesystem permissions.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file      Path to the file.
-	 * @param int    $mode      Optional. The permissions as octal number, usually 0644 for files, 0755 for dirs.
-	 * @param bool   $recursive Optional. If set True changes file group recursively. Defaults to False.
-	 * @return bool|string
+	 * @param string    $file      Path to the file.
+	 * @param int|false $mode      Optional. The permissions as octal number, usually 0644 for files,
+	 *                             0755 for directories. Default false.
+	 * @param bool      $recursive Optional. If set to true, changes file permissions recursively.
+	 *                             Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function chmod( $file, $mode = false, $recursive = false ) {
 		return false;
 	}
 
 	/**
-	 * Get the file owner.
+	 * Gets the file owner.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
-	 * 
+	 *
 	 * @param string $file Path to the file.
-	 * @return string|bool Username of the user or false on error.
+	 * @return string|false Username of the owner on success, false on failure.
 	 */
 	public function owner( $file ) {
 		return false;
 	}
 
 	/**
-	 * Get the file's group.
+	 * Gets the file's group.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Path to the file.
-	 * @return string|bool The group or false on error.
+	 * @return string|false The group on success, false on failure.
 	 */
 	public function group( $file ) {
 		return false;
 	}
 
 	/**
-	 * Copy a file.
+	 * Copies a file.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $source      Path to the source file.
-	 * @param string $destination Path to the destination file.
-	 * @param bool   $overwrite   Optional. Whether to overwrite the destination file if it exists.
-	 *                            Default false.
-	 * @param int    $mode        Optional. The permissions as octal number, usually 0644 for files, 0755 for dirs.
-	 *                            Default false.
-	 * @return bool True if file copied successfully, False otherwise.
+	 * @param string    $source      Path to the source file.
+	 * @param string    $destination Path to the destination file.
+	 * @param bool      $overwrite   Optional. Whether to overwrite the destination file if it exists.
+	 *                               Default false.
+	 * @param int|false $mode        Optional. The permissions as octal number, usually 0644 for files,
+	 *                               0755 for dirs. Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function copy( $source, $destination, $overwrite = false, $mode = false ) {
 		return false;
 	}
 
 	/**
-	 * Move a file.
+	 * Moves a file.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -619,38 +635,36 @@ class WP_Filesystem_Base {
 	 * @param string $destination Path to the destination file.
 	 * @param bool   $overwrite   Optional. Whether to overwrite the destination file if it exists.
 	 *                            Default false.
-	 * @return bool True if file copied successfully, False otherwise.
+	 * @return bool True on success, false on failure.
 	 */
 	public function move( $source, $destination, $overwrite = false ) {
 		return false;
 	}
 
 	/**
-	 * Delete a file or directory.
+	 * Deletes a file or directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file      Path to the file.
-	 * @param bool   $recursive Optional. If set True changes file group recursively. Defaults to False.
-	 *                          Default false.
-	 * @param bool   $type      Type of resource. 'f' for file, 'd' for directory.
-	 *                          Default false.
-	 * @return bool True if the file or directory was deleted, false on failure.
+	 * @param string       $file      Path to the file or directory.
+	 * @param bool         $recursive Optional. If set to true, deletes files and folders recursively.
+	 *                                Default false.
+	 * @param string|false $type      Type of resource. 'f' for file, 'd' for directory.
+	 *                                Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function delete( $file, $recursive = false, $type = false ) {
 		return false;
 	}
 
 	/**
-	 * Check if a file or directory exists.
+	 * Checks if a file or directory exists.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file Path to file/directory.
+	 * @param string $file Path to file or directory.
 	 * @return bool Whether $file exists or not.
 	 */
 	public function exists( $file ) {
@@ -658,9 +672,8 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Check if resource is a file.
+	 * Checks if resource is a file.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -672,9 +685,8 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Check if resource is a directory.
+	 * Checks if resource is a directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -686,9 +698,8 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Check if a file is readable.
+	 * Checks if a file is readable.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -700,13 +711,12 @@ class WP_Filesystem_Base {
 	}
 
 	/**
-	 * Check if a file or directory is writable.
+	 * Checks if a file or directory is writable.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $file Path to file.
+	 * @param string $file Path to file or directory.
 	 * @return bool Whether $file is writable.
 	 */
 	public function is_writable( $file ) {
@@ -716,12 +726,11 @@ class WP_Filesystem_Base {
 	/**
 	 * Gets the file's last access time.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Path to file.
-	 * @return int|bool Unix timestamp representing last access time.
+	 * @return int|false Unix timestamp representing last access time, false on failure.
 	 */
 	public function atime( $file ) {
 		return false;
@@ -730,12 +739,11 @@ class WP_Filesystem_Base {
 	/**
 	 * Gets the file modification time.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Path to file.
-	 * @return int|bool Unix timestamp representing modification time.
+	 * @return int|false Unix timestamp representing modification time, false on failure.
 	 */
 	public function mtime( $file ) {
 		return false;
@@ -744,23 +752,21 @@ class WP_Filesystem_Base {
 	/**
 	 * Gets the file size (in bytes).
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $file Path to file.
-	 * @return int|bool Size of the file in bytes.
+	 * @return int|false Size of the file in bytes on success, false on failure.
 	 */
 	public function size( $file ) {
 		return false;
 	}
 
 	/**
-	 * Set the access and modification times of a file.
+	 * Sets the access and modification times of a file.
 	 *
 	 * Note: If $file doesn't exist, it will be created.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -769,52 +775,49 @@ class WP_Filesystem_Base {
 	 *                      Default 0.
 	 * @param int    $atime Optional. Access time to set for file.
 	 *                      Default 0.
-	 * @return bool Whether operation was successful or not.
+	 * @return bool True on success, false on failure.
 	 */
 	public function touch( $file, $time = 0, $atime = 0 ) {
 		return false;
 	}
 
 	/**
-	 * Create a directory.
+	 * Creates a directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
-	 * @param string $path  Path for new directory.
-	 * @param mixed  $chmod Optional. The permissions as octal number, (or False to skip chmod)
-	 *                      Default false.
-	 * @param mixed  $chown Optional. A user name or number (or False to skip chown)
-	 *                      Default false.
-	 * @param mixed  $chgrp Optional. A group name or number (or False to skip chgrp).
-	 *                      Default false.
-	 * @return bool False if directory cannot be created, true otherwise.
+	 * @param string     $path  Path for new directory.
+	 * @param int|false  $chmod Optional. The permissions as octal number (or false to skip chmod).
+	 *                          Default false.
+	 * @param string|int $chown Optional. A user name or number (or false to skip chown).
+	 *                          Default false.
+	 * @param string|int $chgrp Optional. A group name or number (or false to skip chgrp).
+	 *                          Default false.
+	 * @return bool True on success, false on failure.
 	 */
 	public function mkdir( $path, $chmod = false, $chown = false, $chgrp = false ) {
 		return false;
 	}
 
 	/**
-	 * Delete a directory.
+	 * Deletes a directory.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
 	 * @param string $path      Path to directory.
 	 * @param bool   $recursive Optional. Whether to recursively remove files/directories.
 	 *                          Default false.
-	 * @return bool Whether directory is deleted successfully or not.
+	 * @return bool True on success, false on failure.
 	 */
 	public function rmdir( $path, $recursive = false ) {
 		return false;
 	}
 
 	/**
-	 * Get details for files in a directory or a specific file.
+	 * Gets details for files in a directory or a specific file.
 	 *
-	 * @access public
 	 * @since 2.5.0
 	 * @abstract
 	 *
@@ -823,10 +826,10 @@ class WP_Filesystem_Base {
 	 *                               Default true.
 	 * @param bool   $recursive      Optional. Whether to recursively include file details in nested directories.
 	 *                               Default false.
-	 * @return array|bool {
+	 * @return array|false {
 	 *     Array of files. False if unable to list directory contents.
 	 *
-	 *     @type string $name        Name of the file/directory.
+	 *     @type string $name        Name of the file or directory.
 	 *     @type string $perms       *nix representation of permissions.
 	 *     @type int    $permsn      Octal representation of permissions.
 	 *     @type string $owner       Owner name or ID.
@@ -842,4 +845,4 @@ class WP_Filesystem_Base {
 		return false;
 	}
 
-} // WP_Filesystem_Base
+}
