@@ -30,7 +30,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Setting type.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var string
 	 */
 	public $type = self::TYPE;
@@ -39,7 +38,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Default setting value.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var array
 	 *
 	 * @see wp_get_nav_menu_object()
@@ -55,7 +53,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Default transport.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var string
 	 */
 	public $transport = 'postMessage';
@@ -66,7 +63,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * A negative value represents a placeholder ID for a new menu not yet saved.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var int
 	 */
 	public $term_id;
@@ -80,7 +76,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * a real term.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var int
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::update()
@@ -92,7 +87,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Whether or not update() was called.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 * @var bool
 	 */
 	protected $is_updated = false;
@@ -106,7 +100,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * When status is error, the error is stored in `$update_error`.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var string updated|inserted|deleted|error
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::update()
@@ -118,7 +111,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Any error object returned by wp_update_nav_menu_object() when setting is updated.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 * @var WP_Error
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::update()
@@ -132,14 +124,13 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Any supplied $args override class property defaults.
 	 *
 	 * @since 4.3.0
-	 * @access public
-	 *
-	 * @param WP_Customize_Manager $manager Bootstrap Customizer instance.
-	 * @param string               $id      An specific ID of the setting. Can be a
-	 *                                      theme mod or option name.
-	 * @param array                $args    Optional. Setting arguments.
 	 *
 	 * @throws Exception If $id is not valid for this setting type.
+	 *
+	 * @param WP_Customize_Manager $manager Customizer bootstrap instance.
+	 * @param string               $id      A specific ID of the setting.
+	 *                                      Can be a theme mod or option name.
+	 * @param array                $args    Optional. Setting arguments.
 	 */
 	public function __construct( WP_Customize_Manager $manager, $id, array $args = array() ) {
 		if ( empty( $manager->nav_menus ) ) {
@@ -159,14 +150,13 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Get the instance data for a given widget setting.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see wp_get_nav_menu_object()
 	 *
 	 * @return array Instance data.
 	 */
 	public function value() {
-		if ( $this->is_previewed && $this->_previewed_blog_id === get_current_blog_id() ) {
+		if ( $this->is_previewed && get_current_blog_id() === $this->_previewed_blog_id ) {
 			$undefined  = new stdClass(); // Symbol.
 			$post_value = $this->post_value( $undefined );
 
@@ -189,7 +179,7 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 					$value['auto_add'] = false;
 
 					if ( isset( $nav_menu_options['auto_add'] ) && is_array( $nav_menu_options['auto_add'] ) ) {
-						$value['auto_add'] = in_array( $term->term_id, $nav_menu_options['auto_add'] );
+						$value['auto_add'] = in_array( $term->term_id, $nav_menu_options['auto_add'], true );
 					}
 				}
 			}
@@ -198,6 +188,7 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 				$value = $this->default;
 			}
 		}
+
 		return $value;
 	}
 
@@ -206,7 +197,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 *
 	 * @since 4.3.0
 	 * @since 4.4.0 Added boolean return value
-	 * @access public
 	 *
 	 * @see WP_Customize_Manager::post_value()
 	 *
@@ -217,9 +207,9 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			return false;
 		}
 
-		$undefined = new stdClass();
+		$undefined      = new stdClass();
 		$is_placeholder = ( $this->term_id < 0 );
-		$is_dirty = ( $undefined !== $this->post_value( $undefined ) );
+		$is_dirty       = ( $undefined !== $this->post_value( $undefined ) );
 		if ( ! $is_placeholder && ! $is_dirty ) {
 			return false;
 		}
@@ -240,13 +230,12 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Filters the wp_get_nav_menus() result to ensure the inserted menu object is included, and the deleted one is removed.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see wp_get_nav_menus()
 	 *
-	 * @param array $menus An array of menu objects.
-	 * @param array $args  An array of arguments used to retrieve menu objects.
-	 * @return array
+	 * @param WP_Term[] $menus An array of menu objects.
+	 * @param array     $args  An array of arguments used to retrieve menu objects.
+	 * @return WP_Term[] Array of menu objects.
 	 */
 	public function filter_wp_get_nav_menus( $menus, $args ) {
 		if ( get_current_blog_id() !== $this->_previewed_blog_id ) {
@@ -254,8 +243,8 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 		}
 
 		$setting_value = $this->value();
-		$is_delete = ( false === $setting_value );
-		$index = -1;
+		$is_delete     = ( false === $setting_value );
+		$index         = -1;
 
 		// Find the existing menu item's position in the list.
 		foreach ( $menus as $i => $menu ) {
@@ -272,26 +261,32 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			}
 		} else {
 			// Handle menus being updated or inserted.
-			$menu_obj = (object) array_merge( array(
-				'term_id'          => $this->term_id,
-				'term_taxonomy_id' => $this->term_id,
-				'slug'             => sanitize_title( $setting_value['name'] ),
-				'count'            => 0,
-				'term_group'       => 0,
-				'taxonomy'         => self::TAXONOMY,
-				'filter'           => 'raw',
-			), $setting_value );
+			$menu_obj = (object) array_merge(
+				array(
+					'term_id'          => $this->term_id,
+					'term_taxonomy_id' => $this->term_id,
+					'slug'             => sanitize_title( $setting_value['name'] ),
+					'count'            => 0,
+					'term_group'       => 0,
+					'taxonomy'         => self::TAXONOMY,
+					'filter'           => 'raw',
+				),
+				$setting_value
+			);
 
 			array_splice( $menus, $index, ( -1 === $index ? 0 : 1 ), array( $menu_obj ) );
 		}
 
 		// Make sure the menu objects get re-sorted after an update/insert.
 		if ( ! $is_delete && ! empty( $args['orderby'] ) ) {
-			$menus = wp_list_sort( $menus, array(
-				$args['orderby'] => 'ASC',
-			) );
+			$menus = wp_list_sort(
+				$menus,
+				array(
+					$args['orderby'] => 'ASC',
+				)
+			);
 		}
-		// @todo add support for $args['hide_empty'] === true
+		// @todo Add support for $args['hide_empty'] === true.
 
 		return $menus;
 	}
@@ -300,7 +295,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Temporary non-closure passing of orderby value to function.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 * @var string
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::filter_wp_get_nav_menus()
@@ -315,7 +309,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 *
 	 * @since 4.3.0
 	 * @deprecated 4.7.0 Use wp_list_sort()
-	 * @access protected
 	 *
 	 * @param object $menu1
 	 * @param object $menu2
@@ -336,7 +329,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Requesting a nav_menu object by anything but ID is not supported.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see wp_get_nav_menu_object()
 	 *
@@ -368,7 +360,8 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			return $menu_obj;
 		}
 
-		$menu_obj = (object) array_merge( array(
+		$menu_obj = (object) array_merge(
+			array(
 				'term_id'          => $this->term_id,
 				'term_taxonomy_id' => $this->term_id,
 				'slug'             => sanitize_title( $setting_value['name'] ),
@@ -376,7 +369,9 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 				'term_group'       => 0,
 				'taxonomy'         => self::TAXONOMY,
 				'filter'           => 'raw',
-			), $setting_value );
+			),
+			$setting_value
+		);
 
 		return $menu_obj;
 	}
@@ -385,17 +380,16 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Filters the nav_menu_options option to include this menu's auto_add preference.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param array $nav_menu_options Nav menu options including auto_add.
-	 * @return array (Kaybe) modified nav menu options.
+	 * @return array (Maybe) modified nav menu options.
 	 */
 	public function filter_nav_menu_options( $nav_menu_options ) {
-		if ( $this->_previewed_blog_id !== get_current_blog_id() ) {
+		if ( get_current_blog_id() !== $this->_previewed_blog_id ) {
 			return $nav_menu_options;
 		}
 
-		$menu = $this->value();
+		$menu             = $this->value();
 		$nav_menu_options = $this->filter_nav_menu_options_value(
 			$nav_menu_options,
 			$this->term_id,
@@ -412,7 +406,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * we remove that in this override.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @param array $value The value to sanitize.
 	 * @return array|false|null Null if an input isn't valid. False if it is marked for deletion.
@@ -435,8 +428,8 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			'parent'      => 0,
 			'auto_add'    => false,
 		);
-		$value = array_merge( $default, $value );
-		$value = wp_array_slice_assoc( $value, array_keys( $default ) );
+		$value   = array_merge( $default, $value );
+		$value   = wp_array_slice_assoc( $value, array_keys( $default ) );
 
 		$value['name']        = trim( esc_html( $value['name'] ) ); // This sanitization code is used in wp-admin/nav-menus.php.
 		$value['description'] = sanitize_text_field( $value['description'] );
@@ -456,7 +449,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 *
 	 * See {@see 'customize_save_response'}.
 	 *
-	 * @access protected
 	 * @since 4.3.0
 	 * @var array
 	 *
@@ -474,7 +466,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * To delete a menu, the client can send false as the value.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @see wp_update_nav_menu_object()
 	 *
@@ -513,23 +504,23 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 					$this->update_error  = $r;
 				} else {
 					$this->update_status = 'deleted';
-					$auto_add = false;
+					$auto_add            = false;
 				}
 			}
 		} else {
 			// Insert or update menu.
-			$menu_data = wp_array_slice_assoc( $value, array( 'description', 'parent' ) );
+			$menu_data              = wp_array_slice_assoc( $value, array( 'description', 'parent' ) );
 			$menu_data['menu-name'] = $value['name'];
 
-			$menu_id = $is_placeholder ? 0 : $this->term_id;
-			$r = wp_update_nav_menu_object( $menu_id, wp_slash( $menu_data ) );
-			$original_name = $menu_data['menu-name'];
+			$menu_id              = $is_placeholder ? 0 : $this->term_id;
+			$r                    = wp_update_nav_menu_object( $menu_id, wp_slash( $menu_data ) );
+			$original_name        = $menu_data['menu-name'];
 			$name_conflict_suffix = 1;
 			while ( is_wp_error( $r ) && 'menu_exists' === $r->get_error_code() ) {
 				$name_conflict_suffix += 1;
-				/* translators: 1: original menu name, 2: duplicate count */
+				/* translators: 1: Original menu name, 2: Duplicate count. */
 				$menu_data['menu-name'] = sprintf( __( '%1$s (%2$d)' ), $original_name, $name_conflict_suffix );
-				$r = wp_update_nav_menu_object( $menu_id, wp_slash( $menu_data ) );
+				$r                      = wp_update_nav_menu_object( $menu_id, wp_slash( $menu_data ) );
 			}
 
 			if ( is_wp_error( $r ) ) {
@@ -565,7 +556,7 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 				}
 
 				$post_value = $setting->post_value( null );
-				if ( ! is_null( $post_value ) && $this->previous_term_id === intval( $post_value ) ) {
+				if ( ! is_null( $post_value ) && intval( $post_value ) === $this->previous_term_id ) {
 					$this->manager->set_post_value( $setting->id, $this->term_id );
 					$setting->save();
 				}
@@ -584,7 +575,7 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 				}
 
 				$widget_instance['nav_menu'] = $this->term_id;
-				$updated_widget_instance = $this->manager->widgets->sanitize_widget_js_instance( $widget_instance );
+				$updated_widget_instance     = $this->manager->widgets->sanitize_widget_js_instance( $widget_instance );
 				$this->manager->set_post_value( $nav_menu_widget_setting->id, $updated_widget_instance );
 				$nav_menu_widget_setting->save();
 
@@ -597,7 +588,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Updates a nav_menu_options array.
 	 *
 	 * @since 4.3.0
-	 * @access protected
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::filter_nav_menu_options()
 	 * @see WP_Customize_Nav_Menu_Setting::update()
@@ -613,7 +603,8 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			$nav_menu_options['auto_add'] = array();
 		}
 
-		$i = array_search( $menu_id, $nav_menu_options['auto_add'] );
+		$i = array_search( $menu_id, $nav_menu_options['auto_add'], true );
+
 		if ( $auto_add && false === $i ) {
 			array_push( $nav_menu_options['auto_add'], $this->term_id );
 		} elseif ( ! $auto_add && false !== $i ) {
@@ -627,7 +618,6 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 	 * Export data for the JS client.
 	 *
 	 * @since 4.3.0
-	 * @access public
 	 *
 	 * @see WP_Customize_Nav_Menu_Setting::update()
 	 *
@@ -654,7 +644,7 @@ class WP_Customize_Nav_Menu_Setting extends WP_Customize_Setting {
 			$data['widget_nav_menu_updates'],
 			$this->_widget_nav_menu_updates
 		);
-		$this->_widget_nav_menu_updates = array();
+		$this->_widget_nav_menu_updates  = array();
 
 		return $data;
 	}
